@@ -288,7 +288,8 @@ on_list_thread (const GList *threads, gpointer user_data)
 		else
 			pic = NULL;
 
-		if (frame->address == 0)
+		if ((dma_debugger_queue_is_supported (self->debugger, HAS_CPU) && (frame->address == 0))
+			|| (frame->function == NULL))
 		{
 			/* Missing frame address, request more information */
 			GtkTreeRowReference* reference;
@@ -447,14 +448,18 @@ dma_threads_create_gui(DmaThreads *self)
 	gtk_tree_view_column_set_title (column, _("Function"));
 	gtk_tree_view_append_column (self->list, column);
 	
-	column = gtk_tree_view_column_new ();
-	renderer = gtk_cell_renderer_text_new ();
-	gtk_tree_view_column_pack_start (column, renderer, TRUE);
-	gtk_tree_view_column_add_attribute (column, renderer, "text",
-										THREAD_ADDR_COLUMN);
-	gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_AUTOSIZE);
-	gtk_tree_view_column_set_title (column, _("Address"));
-	gtk_tree_view_append_column (self->list, column);
+	if (dma_debugger_queue_is_supported (self->debugger, HAS_CPU))
+	{
+		/* Display address only if debugger has such concept */
+		column = gtk_tree_view_column_new ();
+		renderer = gtk_cell_renderer_text_new ();
+		gtk_tree_view_column_pack_start (column, renderer, TRUE);
+		gtk_tree_view_column_add_attribute (column, renderer, "text",
+											THREAD_ADDR_COLUMN);
+		gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_AUTOSIZE);
+		gtk_tree_view_column_set_title (column, _("Address"));
+		gtk_tree_view_append_column (self->list, column);
+	}
 	
 	/* Create popup menu */
 	ui = anjuta_shell_get_ui (ANJUTA_PLUGIN(self->plugin)->shell, NULL);
@@ -500,19 +505,6 @@ on_program_moved (DmaThreads *self, guint pid, gint thread)
 	dma_threads_update (self);
 }
 
-static void
-on_debugger_started (DmaThreads *self)
-{
-	dma_threads_create_gui (self);
-}
-
-static void
-on_debugger_stopped (DmaThreads *self)
-{
-	dma_threads_clear (self);
-	dma_destroy_threads_gui (self);
-}
-
 static gboolean
 on_mark_selected_thread (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, gpointer user_data)
 {
@@ -560,6 +552,27 @@ on_frame_changed (DmaThreads *self, guint frame, gint thread)
 	}
 }
 
+static void
+on_program_exited (DmaThreads *self)
+{
+	g_signal_handlers_disconnect_by_func (self->plugin, G_CALLBACK (on_program_exited), self);
+	g_signal_handlers_disconnect_by_func (self->plugin, G_CALLBACK (on_program_moved), self);
+	g_signal_handlers_disconnect_by_func (self->plugin, G_CALLBACK (on_frame_changed), self);
+	
+	dma_threads_clear (self);
+	dma_destroy_threads_gui (self);
+}
+
+static void
+on_program_started (DmaThreads *self)
+{
+	dma_threads_create_gui (self);
+	
+	g_signal_connect_swapped (self->plugin, "program-exited", G_CALLBACK (on_program_exited), self);
+	g_signal_connect_swapped (self->plugin, "program-moved", G_CALLBACK (on_program_moved), self);
+	g_signal_connect_swapped (self->plugin, "frame-changed", G_CALLBACK (on_frame_changed), self);
+}
+
 /* Constructor & Destructor
  *---------------------------------------------------------------------------*/
 
@@ -577,19 +590,14 @@ dma_threads_new (DebugManagerPlugin *plugin)
 
 	/* Register actions */
 	ui = anjuta_shell_get_ui (ANJUTA_PLUGIN(self->plugin)->shell, NULL);
-	DEBUG_PRINT("add actions");
 	self->action_group =
 		anjuta_ui_add_action_group_entries (ui, "ActionGroupThread",
 											_("Thread operations"),
 											actions_threads,
 											G_N_ELEMENTS (actions_threads),
 											GETTEXT_PACKAGE, TRUE, self);
-	DEBUG_PRINT("add actions end");
 
-	g_signal_connect_swapped (self->plugin, "debugger-started", G_CALLBACK (on_debugger_started), self);
-	g_signal_connect_swapped (self->plugin, "debugger-stopped", G_CALLBACK (on_debugger_stopped), self);
-	g_signal_connect_swapped (self->plugin, "program-moved", G_CALLBACK (on_program_moved), self);
-	g_signal_connect_swapped (self->plugin, "frame-changed", G_CALLBACK (on_frame_changed), self);
+	g_signal_connect_swapped (self->plugin, "program-started", G_CALLBACK (on_program_started), self);
 	
 	return self;
 }
@@ -600,15 +608,9 @@ dma_threads_free (DmaThreads *self)
 	AnjutaUI *ui;
 	
 	g_return_if_fail (self != NULL);
-
+	
 	/* Disconnect from debugger */
-	if (self->debugger != NULL)
-	{	
-		g_signal_handlers_disconnect_by_func (self->plugin, G_CALLBACK (on_debugger_started), self);
-		g_signal_handlers_disconnect_by_func (self->plugin, G_CALLBACK (on_debugger_stopped), self);
-		g_signal_handlers_disconnect_by_func (self->plugin, G_CALLBACK (on_program_moved), self);
-		g_signal_handlers_disconnect_by_func (self->plugin, G_CALLBACK (on_frame_changed), self);
-	}
+	g_signal_handlers_disconnect_matched (self->plugin, G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, self);	
 
 	/* Remove menu actions */
 	ui = anjuta_shell_get_ui (ANJUTA_PLUGIN (self->plugin)->shell, NULL);
