@@ -36,7 +36,7 @@
 #include "sourceview.h"
 
 #define PREFS_GLADE PACKAGE_DATA_DIR"/glade/sourceview.glade"
-#define ICON_FILE "sourceview.png"
+#define ICON_FILE "anjuta-editor-sourceview-plugin-48.png"
 
 #define COLOR_USE_THEME_BUTTON "preferences_toggle:bool:1:0:sourceview.color.use_theme"
 #define COLOR_TEXT "preferences_color:color:#FFFFFF:0:sourceview.color.text"
@@ -166,7 +166,7 @@ ipreferences_unmerge(IAnjutaPreferences* ipref, AnjutaPreferences* prefs, GError
 	g_signal_handlers_disconnect_by_func(G_OBJECT(plugin->check_font), 
 		G_CALLBACK(on_font_check_toggled), gxml);
 	
-	anjuta_preferences_dialog_remove_page(ANJUTA_PREFERENCES_DIALOG(prefs), _("GtkSourceView Editor"));
+	anjuta_preferences_remove_page(prefs, _("GtkSourceView Editor"));
 	g_object_unref(gxml);
 	gxml = NULL;
 }
